import { renderEditor, renderCodeBlock } from "prism-code-editor/ssr";
import { numLines } from "prism-code-editor";
import { languages, tokenizeText, highlightTokens } from "prism-code-editor/prism";
const parseValue = (value, numLines2) => {
  if (value[0] == "{") return parseRanges(value, numLines2);
  if (value[0] == '"' || value[0] == "'") value = value.slice(1, -1);
  if (!value || value == "true") return true;
  if (value == "false") return false;
  if (value == "null") return null;
  if (!isNaN(+value)) return +value;
  return value;
};
const parseRanges = (ranges, numLines2) => {
  let pattern = /(\d+)(?:\s*-\s*(\d+))?/g;
  let match;
  let result = /* @__PURE__ */ new Set();
  while (match = pattern.exec(ranges)) {
    let start = +match[1];
    let end = Math.min(+match[2] || start, numLines2);
    while (start <= end) result.add(start++);
  }
  return result;
};
const getRanges = (props, prop) => {
  let ranges = props[prop];
  delete props[prop];
  if (ranges instanceof Set) return ranges;
};
const parseMeta = (meta, numLines2) => {
  let result = {};
  let pattern = /([^\s"'{}=]+)(?:\s*=\s*("[^"]*"|'[^']*'|\{[^}]*\}|[^\s"'{}=]+))?/g;
  let match;
  while (match = pattern.exec(meta)) {
    result[match[1]] = parseValue(match[2] || "", numLines2);
  }
  return result;
};
const createEditor = (props) => {
  return renderEditor(props);
};
const createCodeBlock = (props) => {
  const highlight = getRanges(props, "highlight");
  const ins = getRanges(props, "ins");
  const del = getRanges(props, "del");
  if (highlight || ins || del) {
    props.addLineClass = (line) => {
      if (highlight?.has(line)) return "highlighted";
      if (ins?.has(line)) return "inserted";
      if (del?.has(line)) return "deleted";
      return "";
    };
  }
  return renderCodeBlock(props);
};
const markedPrismCodeEditor = ({
  editorsOnly,
  defaultEditorProps,
  defaultCodeBlockProps,
  customRenderer,
  inline,
  silenceWarnings
} = {}) => {
  return {
    renderer: {
      code(token) {
        const match = /(\S*)(.*)/.exec(token.lang || "");
        const lang = match[1] || "text";
        const code = token.text;
        const meta = parseMeta(match[2], numLines(code));
        const isEditor = meta.editor;
        if (editorsOnly && isEditor == null) return false;
        meta.value = code;
        meta.language = lang;
        delete meta.editor;
        if (!languages[lang] && !silenceWarnings) {
          console.warn(
            `marked-prism-code-editor: Unregistered language '${lang}' found in code block. Syntax highlighting will be disabled.`
          );
        }
        const renderFunc = isEditor ? createEditor : createCodeBlock;
        const merged = {
          ...isEditor ? defaultEditorProps : defaultCodeBlockProps,
          ...meta
        };
        return customRenderer ? customRenderer(merged, renderFunc, !!isEditor) : renderFunc(merged);
      },
      codespan: (token) => {
        let text = token.text;
        let langStart = text.lastIndexOf("{:");
        if (!inline || langStart < 1 || text.slice(-1) != "}") return false;
        const lang = text.slice(langStart + 2, -1);
        const code = text.slice(0, langStart);
        const grammar = languages[lang];
        if (!grammar) {
          if (!silenceWarnings) {
            console.warn(
              `marked-prism-code-editor: Unregistered language '${lang}' found in inline code. Highlighting is skipped.`
            );
          }
          return false;
        }
        const tokens = tokenizeText(code, grammar);
        inline.tokenizeCallback?.(tokens, lang);
        return `<code class="language-${lang.replace(/&/g, "&amp;").replace(/"/g, "&quot;")}">${highlightTokens(tokens)}</code>`;
      }
    }
  };
};
export {
  markedPrismCodeEditor
};
//# sourceMappingURL=index.js.map
